from django.utils.translation import gettext_lazy as _
from django.contrib.auth.models import User
from django.db import models


class Restaurant(models.Model):
    name = models.CharField(max_length=30, verbose_name=_("NameRestaurant"))

    address = models.CharField(max_length=70, verbose_name=_("AddressRestaurant"))

    photo = models.ImageField(upload_to="photo", default=1, verbose_name=_("PhotoRestaurant"))

    description = models.TextField(max_length=1000, verbose_name=_("DescriptionRestaurant"))

    def __str__(self):
        return f'{self.name}'


class Event(models.Model):
    place = models.ForeignKey(Restaurant, on_delete=models.CASCADE,
                              verbose_name=_("PlaceEvent"), related_name="Place")

    date = models.DateTimeField(verbose_name=_("DateEvent"))

    users = models.ManyToManyField(User, blank=True, verbose_name=_("ParticipantsEvent"), related_name="participants")

    def __str__(self):
        return f'{self.place} - {self.date}'

    class Meta:
        permissions = [
            ("can_see_all_user_in_event", "Can see all user in event"),
        ]



