from django.shortcuts import render, redirect
from django.urls import reverse, reverse_lazy
from django.views import View
from django.views.generic import CreateView, DetailView, UpdateView, DeleteView
from django.contrib.auth.mixins import PermissionRequiredMixin, UserPassesTestMixin

from webapp.forms import EventForm
from webapp.models import Event


def index_view(request):
    return render(request, "index.html")


class EventView(View):
    def get(self, request, *args, **kwargs):
        events = Event.objects.all().order_by("-date")
        context = {"events": events}
        return render(request, "event_list.html", context)


class EventCreateView(PermissionRequiredMixin, CreateView):
    model = Event
    template_name = "event_create.html"
    form_class = EventForm
    permission_required = "webapp.add_event"

    def get_success_url(self):
        return reverse("detail_events", kwargs={"pk": self.object.pk})


class EventDetailView(DetailView):
    model = Event
    template_name = "event_detail.html"
    context_object_name = "event"


class EventUpdateView(PermissionRequiredMixin, UpdateView):
    model = Event
    template_name = "event_update.html"
    form_class = EventForm
    permission_required = "webapp.change_event"

    def get_success_url(self):
        return reverse("detail_events", kwargs={"pk": self.object.pk})


class EventDeleteView(PermissionRequiredMixin, DeleteView):
    model = Event
    template_name = "event_delete.html"
    success_url = reverse_lazy("list_events")
    permission_required = "webapp.delete_event"


class ParticipateView(UserPassesTestMixin, UpdateView):
    model = Event
    template_name = "participate.html"
    fields = ["users"]

    def test_func(self):
        return self.request.user.profile.birth_date and self.request.user.profile.phone_number and \
               self.request.user.profile.gender

    def post(self, request, *args, **kwargs):
        participate = self.get_object()
        participate.users.add(self.request.user)
        return redirect('list_events')


class ParticipateListInEventView(PermissionRequiredMixin, DetailView):
    model = Event
    template_name = "all_user_in_event.html"
    permission_required = "webapp.can_see_all_user_in_event"






